@@ -27,10 +27,10 @@
 #include <QRegularExpression>
 
 #include "formatter/Formatter.h"
+#include "systemstats/SensorInfo.h"
 
 #include "Sensor.h"
 #include "SensorDaemonInterface_p.h"
-#include "SensorInfo_p.h"
 #include "SensorQuery.h"
 #include "SensorGroup_p.h"
 
